Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7)

Unified Diff: chrome/browser/autocomplete/autocomplete.h

Issue 7822009: Fix crash in CanFindIntranetURL() due to FixupUserInput() changing the AutocompleteInput's text_ ... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 9 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/autocomplete/autocomplete.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/autocomplete/autocomplete.h
===================================================================
--- chrome/browser/autocomplete/autocomplete.h (revision 98899)
+++ chrome/browser/autocomplete/autocomplete.h (working copy)
@@ -266,9 +266,9 @@
const string16& text() const { return text_; }
// Use of this setter is risky, since no other internal state is updated
- // besides |text_|. Only callers who know that they're not changing the
- // type/scheme/etc. should use this.
- void set_text(const string16& text) { text_ = text; }
+ // besides |text_| and |parts_|. Only callers who know that they're not
+ // changing the type/scheme/etc. should use this.
+ void UpdateText(const string16& text, const url_parse::Parsed& parts);
// User's desired TLD, if one is not already present in the text to
// autocomplete. When this is non-empty, it also implies that "www." should
« no previous file with comments | « no previous file | chrome/browser/autocomplete/autocomplete.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698